@@ -623,7 +623,7 @@ function IsFunc(Query)
 end
 
 function Parser(Query,launguage)
-	print("111",Query,launguage)
+	print(Query)
 	Query=GB2UTF8(Query)
 	
 	HandleNo=0
@@ -639,16 +639,11 @@ function Parser(Query,launguage)
 	local Query,Condition,Operation,Speedup=Init(Query)
 
 	if Condition ~= "" then
-		ConditionLower = string.lower(Condition)
-		B,E=string.find(ConditionLower,"%$orion")
-		if B == nil then
-			Condition="Condition(\""..Condition.."\")\n"
-		else
-			l=string.sub(Condition,1,B-1)
-			r=string.sub(Condition,E+1)
-			Condition="OriOn()\nCondition(\""..l..r.."\")\n"
-		end
+		Condition="OriOn()\nCondition(\""..Condition.."\")\n"
+	else
+		Condition="OriOn()\n"
 	end
+	
 	if IsFunc(Query) == 1 then
 		Script=GetOperation(Query)
 		Script=Script.."return Ret\n"
